@@ -350,23 +350,23 @@ extern SbkConverter **SbkPySide6_Qt3DRenderTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 0, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 1, // QList<Qt3DRender::QRayCasterHit >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 2, // QList<Qt3DRender::QLayer* >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 3, // QList<Qt3DCore::QNode* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 4, // QList<Qt3DRender::QAbstractTextureImage* >
-    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 5, // QList<Qt3DCore::QComponent* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 6, // QList<Qt3DRender::QParameter* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 7, // QList<Qt3DRender::QTechnique* >
-    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 8, // const QList<QObject* > &
-    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 9, // QList<QByteArray >
-    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 10, // const QList<qreal > &
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 11, // QList<Qt3DRender::QFilterKey* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 12, // QList<Qt3DRender::QRenderState* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 13, // QList<Qt3DRender::QRenderTargetOutput* >
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 14, // const QList<Qt3DRender::QSortPolicy::SortType > &
-    SBK_QT3DRENDER_QLIST_INT_IDX                             = 15, // const QList<int > &
-    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 16, // QList<Qt3DRender::QRenderPass* >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QNODEPTR_IDX               = 0, // QList<Qt3DCore::QNode* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QFILTERKEYPTR_IDX        = 1, // QList<Qt3DRender::QFilterKey* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QPARAMETERPTR_IDX        = 2, // QList<Qt3DRender::QParameter* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERPASSPTR_IDX       = 3, // QList<Qt3DRender::QRenderPass* >
+    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 4, // QList<QObject* >
+    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 5, // QList<QByteArray >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QENTITYPTR_IDX             = 6, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERSTATEPTR_IDX      = 7, // QList<Qt3DRender::QRenderState* >
+    SBK_QT3DRENDER_QLIST_QREAL_IDX                           = 8, // QList<qreal >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QTECHNIQUEPTR_IDX        = 9, // QList<Qt3DRender::QTechnique* >
+    SBK_QT3DRENDER_QLIST_QT3DCORE_QCOMPONENTPTR_IDX          = 10, // QList<Qt3DCore::QComponent* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRENDERTARGETOUTPUTPTR_IDX = 11, // QList<Qt3DRender::QRenderTargetOutput* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX = 12, // QList<Qt3DRender::QSortPolicy::SortType >
+    SBK_QT3DRENDER_QLIST_INT_IDX                             = 13, // QList<int >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QLAYERPTR_IDX            = 14, // QList<Qt3DRender::QLayer* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 15, // QList<Qt3DRender::QAbstractTextureImage* >
+    SBK_QT3DRENDER_QLIST_QT3DRENDER_QRAYCASTERHIT_IDX        = 16, // QList<Qt3DRender::QRayCasterHit >
     SBK_QT3DRENDER_QLIST_QVARIANT_IDX                        = 17, // QList<QVariant >
     SBK_QT3DRENDER_QLIST_QSTRING_IDX                         = 18, // QList<QString >
     SBK_QT3DRENDER_QMAP_QSTRING_QVARIANT_IDX                 = 19, // QMap<QString,QVariant >
